@@ -255,6 +255,20 @@ public class LdapGlobalFolderCreator {
             public String getAuthId() {
                 throw new UnsupportedOperationException();
             }
+
+            public String getHash() {
+                return null;
+            }
+
+            public void setLocalIp(String ip) {
+                // TODO Auto-generated method stub
+                
+            }
+
+			public void setHash(String hash) {
+				// TODO Auto-generated method stub
+				
+			}
         };
     }
 
