@@ -70,16 +70,17 @@ import javax.naming.ldap.PagedResultsControl;
 import javax.naming.ldap.PagedResultsResponseControl;
 import javax.naming.ldap.SortControl;
 import javax.naming.ldap.SortKey;
-import com.openexchange.contacts.ldap.contacts.LdapContactInterface.Order;
 import com.openexchange.contacts.ldap.contacts.LdapContactInterface.SortInfo;
 import com.openexchange.contacts.ldap.exceptions.LdapException;
 import com.openexchange.contacts.ldap.exceptions.LdapException.Code;
 import com.openexchange.contacts.ldap.property.FolderProperties;
 import com.openexchange.contacts.ldap.property.Mappings;
+import com.openexchange.contacts.ldap.property.FolderProperties.DerefAliases;
 import com.openexchange.contacts.ldap.property.FolderProperties.SearchScope;
 import com.openexchange.contacts.ldap.property.FolderProperties.Sorting;
 import com.openexchange.groupware.container.Contact;
 import com.openexchange.groupware.container.DataObject;
+import com.openexchange.groupware.search.Order;
 
 
 /**
@@ -236,7 +237,7 @@ public class LdapJNDIImpl implements LdapInterface {
             }
         } else {
             if (null != sortField && folderprop.getSorting().equals(Sorting.server)) {
-                final SortKey sortKey = new SortKey(getFieldFromColumn(sortField.getField(), distributionlist), sortField.getSort().equals(Order.asc), null);
+                final SortKey sortKey = new SortKey(getFieldFromColumn(sortField.getField(), distributionlist), sortField.getSort().equals(Order.ASCENDING), null);
                 final SortKey[] sortKeyArray = new SortKey[] { sortKey };
                 if (0 == pagesize) {
                     return new Control[] { new SortControl(sortKeyArray, Control.CRITICAL) };
@@ -612,6 +613,15 @@ public class LdapJNDIImpl implements LdapInterface {
         default:
             break;
         }
+        final DerefAliases derefAliases = folderprop.getDerefAliases();
+        if (null != derefAliases) {
+            env.put("java.naming.ldap.derefAliases", derefAliases.toString());
+        }
+        final int pooltimeout = folderprop.getPooltimeout();
+        if (-1 != pooltimeout) {
+            env.put("com.sun.jndi.ldap.connect.pool.timeout", String.valueOf(pooltimeout));
+        }
+        
         return env;
     }
 
