@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,6 +50,7 @@
 package com.openexchange.contacts.ldap.osgi;
 
 import java.util.Hashtable;
+import java.util.Map.Entry;
 import java.util.concurrent.atomic.AtomicBoolean;
 import org.osgi.framework.ServiceRegistration;
 import com.openexchange.config.ConfigurationService;
@@ -104,7 +105,7 @@ public final class LdapActivator extends DeferredActivator {
         if (LOG.isWarnEnabled()) {
             LOG.warn("Absent service: " + clazz.getName());
         }
-        ServiceRegistry.getInstance().removeService(clazz);
+        LDAPServiceRegistry.getInstance().removeService(clazz);
     }
 
     @Override
@@ -112,7 +113,7 @@ public final class LdapActivator extends DeferredActivator {
         if (LOG.isInfoEnabled()) {
             LOG.info("Re-available service: " + clazz.getName());
         }
-        ServiceRegistry.getInstance().addService(clazz, getService(clazz));
+        LDAPServiceRegistry.getInstance().addService(clazz, getService(clazz));
     }
 
     @Override
@@ -122,7 +123,7 @@ public final class LdapActivator extends DeferredActivator {
              * (Re-)Initialize service registry with available services
              */
             {
-                final ServiceRegistry registry = ServiceRegistry.getInstance();
+                final LDAPServiceRegistry registry = LDAPServiceRegistry.getInstance();
                 registry.clearRegistry();
                 final Class<?>[] classes = getNeededServices();
                 for (int i = 0; i < classes.length; i++) {
@@ -146,8 +147,9 @@ public final class LdapActivator extends DeferredActivator {
 
             final PropertyHandler instance = PropertyHandler.getInstance();
             instance.loadProperties();
-            for (final Integer ctx : instance.getContextdetails().keySet()) {
-                final ContextProperties contextProperties = instance.getContextdetails().get(ctx);
+            for (final Entry<Integer, ContextProperties> entry : instance.getContextdetails().entrySet()) {
+                final Integer ctx = entry.getKey();
+                final ContextProperties contextProperties = entry.getValue();
                 for (final FolderProperties folderprop : contextProperties.getFolderproperties()) {
                     final FolderIDAndAdminID createGlobalFolder = LdapGlobalFolderCreator.createGlobalFolder(
                         new ContextImpl(ctx.intValue()),
@@ -174,6 +176,7 @@ public final class LdapActivator extends DeferredActivator {
                 }
             }
         } catch (final Exception e) {
+            LOG.error(e.getMessage(), e);
             throw e;
         } finally {
             if (null != registryFolderCreator) {
@@ -192,7 +195,7 @@ public final class LdapActivator extends DeferredActivator {
             /*
              * Clear service registry
              */
-            ServiceRegistry.getInstance().clearRegistry();
+            LDAPServiceRegistry.getInstance().clearRegistry();
         } catch (final Exception e) {
             LOG.error(e.getMessage(), e);
             throw e;
